# NaiveFea
A python library for the simplest finite element analysis.

You can learn how to use it by example.ipynb. 

This project is a teaching material for students who want to implement FEA with Python in this post on Chaoli forum (in Chinese): 
https://chaoli.club/index.php/6884

Theory document (in Chinese):
https://github.com/MuTong320/NaiveFeaDocument
